@@ -55,76 +55,26 @@ pub fn conn_to_response(conn: Conn) -> Response {
 }
 
 pub fn html(conn: Conn, content: &str) -> Conn {
-    let mut headers = conn.resp_headers;
-    headers.insert(
-        "Content-Type".to_string(),
-        "text/html; charset=utf-8".to_string(),
-    );
-    return Conn {
-        resp_headers: headers,
-        resp_body: content.to_string(),
-        status: 200,
-        ..conn
-    };
+    return with_content_type(conn, content, "text/html; charset=utf-8");
 }
 
 pub fn json(conn: Conn, content: &str) -> Conn {
-    let mut headers = conn.resp_headers;
-    headers.insert(
-        "Content-Type".to_string(),
-        "application/json; charset=utf-8".to_string(),
-    );
-    return Conn {
-        resp_headers: headers,
-        resp_body: content.to_string(),
-        status: 200,
-        ..conn
-    };
+    return with_content_type(conn, content, "application/json; charset=utf-8");
 }
 
 pub fn xml(conn: Conn, content: &str) -> Conn {
-    let mut headers = conn.resp_headers;
-    headers.insert(
-        "Content-Type".to_string(),
-        "application/xml; charset=utf-8".to_string(),
-    );
-    return Conn {
-        resp_headers: headers,
-        resp_body: content.to_string(),
-        status: 200,
-        ..conn
-    };
+    return with_content_type(conn, content, "application/xml; charset=utf-8");
 }
 
 pub fn js(conn: Conn, content: &str) -> Conn {
-    let mut headers = conn.resp_headers;
-    headers.insert(
-        "Content-Type".to_string(),
-        "text/javascript; charset=utf-8".to_string(),
-    );
-    return Conn {
-        resp_headers: headers,
-        resp_body: content.to_string(),
-        status: 200,
-        ..conn
-    };
+    return with_content_type(conn, content, "text/javascript; charset=utf-8");
 }
 
 pub fn css(conn: Conn, content: &str) -> Conn {
-    let mut headers = conn.resp_headers;
-    headers.insert(
-        "Content-Type".to_string(),
-        "text/css; charset=utf-8".to_string(),
-    );
-    return Conn {
-        resp_headers: headers,
-        resp_body: content.to_string(),
-        status: 200,
-        ..conn
-    };
+    return with_content_type(conn, content, "text/css; charset=utf-8");
 }
 
-pub fn custom(conn: Conn, content: &str, content_type: &str) -> Conn {
+pub fn with_content_type(conn: Conn, content: &str, content_type: &str) -> Conn {
     let mut headers = conn.resp_headers;
     headers.insert("Content-Type".to_string(), content_type.to_string());
     return Conn {
@@ -141,7 +91,7 @@ pub fn redirect_to(conn: Conn, to: &str) -> Conn {
     return Conn {
         resp_headers: headers,
         resp_body: "".to_string(),
-        status: 200,
+        status: 302,
         ..conn
     };
 }
